<?php

namespace FiloBlu\Refilo\Model\Exporter;

use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ResourceConnection;
use stdClass;

class Redirects
{
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;
    /**
     * @var Mongo
     */
    private $mongo;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * Menu constructor.
     * @param ResourceConnection $resourceConnection
     * @param ScopeConfigInterface $scopeConfig
     * @param Mongo $mongo
     */
    public function __construct(
        ResourceConnection $resourceConnection,
        ScopeConfigInterface $scopeConfig,
        Mongo $mongo
    ) {
        $this->resourceConnection = $resourceConnection;
        $this->scopeConfig = $scopeConfig;
        $this->mongo = $mongo;
    }

    public function exportRedirects()
    {
        $this->mongo->dropCollection("redirects", $this->scopeConfig->getValue('mongo/general/mongo_general_database'));
        $bulkData = [];
        $query = "SELECT * FROM `filoblu_refilo_redirect`";

        $result = $this->resourceConnection->getConnection()->fetchAll($query);

        foreach ($result as $item) {
            $redirect = new stdClass();

            $redirect->_id = (int)$item['id'];
            $redirect->host = $item['host'];
            $redirect->request_url = $item['request_url'];
            $redirect->target_url = $item['target_url'];
            $redirect->redirect_code = (int)$item['redirect_code'];
            $bulkData[] = $redirect;
        }

        if (!empty($bulkData)) {
            try {
                $this->mongo->update(
                    '_id',
                    $bulkData,
                    'redirects',
                    true,
                    $this->scopeConfig->getValue('mongo/general/mongo_general_database')
                );
            } catch (MongoDB\Driver\Exception\Exception $e) {
                echo $e->getMessage();
            }
        } else {
            try {
                $this->mongo->flushCollection(
                    'redirects',
                    $this->scopeConfig->getValue('mongo/general/mongo_general_database')
                );
            } catch (MongoDB\Driver\Exception\Exception $e) {
                echo $e->getMessage();
            }
        }

    }
}
